Rectangle

Struct Rectangle 

pub struct Rectangle<Space: CoordinateSpace> {
    pub top_left: Coordinates<Space>,
    pub bottom_right: Coordinates<Space>,
}
A 2d rectangle specified with two Coordinates

Fields

top_left: Coordinates<Space>

Top left Coordinates of the rectangle

bottom_right: Coordinates<Space>

Bottom right Coordinates of the rectangle

Implementations

Source

impl<Space: CoordinateSpace> Rectangle<Space>

pub const fn new( top_left: Coordinates<Space>, bottom_right: Coordinates<Space>, ) -> Self

Creates a new rectangle using two Coordinates

pub const fn new_from_coordinates( left: Space::Data, top: Space::Data, right: Space::Data, bottom: Space::Data, ) -> Self

A shortcut for Rectangle::new without having to use Coordinates::new(x, y)

pub fn rotated(&self, rotation: u8) -> Self

Returns a new rectangle that is rotated a number of 90 degree turns around the center of the CoordinateSpace

pub const fn everything() -> Self

Creates a new rectangle that covers the entire CoordinateSpace

pub fn width(&self) -> Space::Data

Calculates the width of the rectangle

pub fn height(&self) -> Space::Data

Calculates the height of the rectangle

pub const fn left(&self) -> Space::Data

Returns the leftmost X coordinate of the rectangle

pub const fn top(&self) -> Space::Data

Returns the topmost Y coordinate of the rectangle

pub const fn right(&self) -> Space::Data

Returns the rightmost X coordinate of the rectangle

pub const fn bottom(&self) -> Space::Data

Returns the bottommost Y coordinate of the rectangle

pub fn iter_coords( &self, ) -> impl Iterator<Item = Coordinates<Space>> + use<'_, Space>

Produces a row-first iterator of every coordinate contained within this rectangle