pub trait Sample<'a, Space: CoordinateSpace> {
type Output: 'a;
// Required method
fn sample(
&mut self,
rect: &Rectangle<Space>,
) -> impl Iterator<Item = (Coordinates<Space>, &'a mut Self::Output)>;
}Expand description
Types that can provide direct hardware access to individual pixels within a given Virtual rectangle shaped selection for reading and writing
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.